from datetime import datetime

from common.utils import logging
from common.utils.appinfo.core import AppInfoService
from common.utils.baseline.core import BaselineService
from common.utils.checkpoint.core import CheckpointService
from common.utils.event.core import EventService
from common.utils.flow.core import FlowService
from common.utils.lookup.core import LookupService
from common.utils.userconfig.core import UserConfigService
from uncommonport.detector.core import UncommonPort


def main():
    """
    Main function for detector
    :return:

    note: this detector is checkpoint based (not pure batch) so we don't need to rerun at 2am
    """
    now = datetime.now()
    flow_service = FlowService()

    uncommonport = UncommonPort(
        BaselineService(),
        CheckpointService(),
        UserConfigService(),
        EventService(),
        flow_service,
        LookupService(flow_service),
        AppInfoService(),
        now
    )

    logger.info("starting uncommon used port")
    uncommonport.run()
    logger.info("ending uncommon used port")


if __name__ == "__main__":
    logger = logging.get_common_logger(__file__)
    logger.info("initializing uncommon used port detector")
    main()
